import _toConsumableArray from "@babel/runtime/helpers/toConsumableArray";
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import { Container } from './Container';
import { Layout } from './Layout';
import { Mark } from './Mark';
import { Renderer } from './Renderer';
export var Chart = /*#__PURE__*/function () {
  function Chart(options) {
    _classCallCheck(this, Chart);

    this.options = options;
    this.renderer = void 0;
    this.containerMap = {};
    this.$groupElList = [];
  }

  _createClass(Chart, [{
    key: "init",
    value: function init() {
      var _this = this;

      var rawData = _toConsumableArray(this.options.data);

      rawData.forEach(function (d, i) {
        d.$unitChartId = "".concat(i);
      });
      this.options.layouts.forEach(function (_ref) {
        var name = _ref.name,
            ls = _ref.layouts;
        var layouts = ls.map(function (layoutOptions) {
          return new Layout(layoutOptions);
        });
        layouts.forEach(function (layout, i, all) {
          layout.setParent(i > 0 ? all[i - 1] : Layout.START_OF());
          layout.setChild(i < all.length - 1 ? all[i + 1] : Layout.END_OF());
        });
        var rootContainer = new Container({
          label: 'root',
          data: rawData,
          parent: undefined,
          children: undefined,
          visualspace: {
            width: _this.options.width,
            height: _this.options.height,
            posX: 0,
            posY: 0,
            padding: _this.options.padding
          }
        });
        rootContainer.applyLayout(layouts[0]);
        _this.containerMap[name] = rootContainer;
      });
      this.renderer = new Renderer({
        canvas: this.options.canvas,
        containerMap: this.containerMap,
        mark: new Mark(this.options.mark),
        onPick: function onPick(e) {
          var item = rawData.find(function (d) {
            return Number(d.$unitChartId) === e.featureId;
          });

          _this.options.onPick(item, [e.x, e.y]);
        }
      });
      this.renderer.init();
    }
  }, {
    key: "render",
    value: function render(renderOptions) {
      this.renderAxis(renderOptions);
      this.renderer.render(renderOptions);
    }
  }, {
    key: "destroy",
    value: function destroy() {
      this.renderer.destroy();
    }
  }, {
    key: "renderAxis",
    value: function renderAxis(_ref2) {
      var _this2 = this;

      var layout = _ref2.layout;
      var canvasWrapper = this.options.canvas.parentElement;
      this.$groupElList.forEach(function (el) {
        return canvasWrapper === null || canvasWrapper === void 0 ? void 0 : canvasWrapper.removeChild(el);
      });
      this.$groupElList = [];
      this.containerMap[layout].children.forEach(function (_ref3) {
        var label = _ref3.label,
            visualspace = _ref3.visualspace;
        var $groupEl = document.createElement('div');
        $groupEl.style.cssText = "position:absolute;top:".concat(visualspace.posY + 8, "px;left:").concat(visualspace.posX, "px;");
        var $groupNameEl = document.createTextNode(label);
        $groupEl.appendChild($groupNameEl);
        canvasWrapper === null || canvasWrapper === void 0 ? void 0 : canvasWrapper.appendChild($groupEl);

        _this2.$groupElList.push($groupEl);
      });
    }
  }]);

  return Chart;
}();
//# sourceMappingURL=Chart.js.map