import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import * as d3 from 'd3';
export var Container = /*#__PURE__*/function () {
  function Container(options) {
    _classCallCheck(this, Container);

    this.options = options;
    this.parent = void 0;
    this.children = void 0;
    this.visualspace = void 0;
    this.data = void 0;
    this.label = void 0;
    this.parent = options.parent;
    this.children = options.children || [];
    this.visualspace = options.visualspace;
    this.data = options.data;
    this.label = options.label;
  }

  _createClass(Container, [{
    key: "applyLayout",
    value: function applyLayout(layout) {
      var l = layout;

      while (l && !l.isEndOf()) {
        this.children = layout.apply(this.children.length && this.children || [this]);
        l = layout.getChild();
      }
    }
  }, {
    key: "getAvailableSpace",
    value: function getAvailableSpace(layout) {
      var width;
      var height;

      switch (layout.aspectRatio) {
        case 'fillX':
          return this.visualspace.width - this.visualspace.padding.left - this.visualspace.padding.right;

        case 'fillY':
          return this.visualspace.height - this.visualspace.padding.top - this.visualspace.padding.bottom;

        case 'maxfill':
        case 'parent':
          width = this.visualspace.width - this.visualspace.padding.left - this.visualspace.padding.right;
          height = this.visualspace.height - this.visualspace.padding.top - this.visualspace.padding.bottom;
          return width * height;

        case 'square':
          width = this.visualspace.width - this.visualspace.padding.left - this.visualspace.padding.right;
          height = this.visualspace.height - this.visualspace.padding.top - this.visualspace.padding.bottom;
          return Math.pow(Math.min(width, height), 2);
      }

      return 0;
    }
  }, {
    key: "makeContainersForPassthrough",
    value: function makeContainersForPassthrough() {
      return [new Container({
        data: this.data,
        label: this.label,
        visualspace: {
          width: 0,
          height: 0,
          posX: 0,
          posY: 0,
          padding: {
            top: 0,
            left: 0,
            bottom: 0,
            right: 0
          }
        },
        parent: this,
        children: this.children
      })];
    }
  }, {
    key: "makeContainersForCategoricalVar",
    value: function makeContainersForCategoricalVar(sharingDomain, // layout: Layout,
    key) {
      var _this = this;

      var newContainers = this.emptyContainersFromKeys(sharingDomain, // layout.subgroup.key,
      key);
      newContainers.forEach(function (c) {
        c.data = _this.data.filter(function (d) {
          // return d[layout.subgroup.key] === c.label;
          return d[key] === c.label;
        });
        c.parent = _this;
      });
      return newContainers;
    }
  }, {
    key: "makeContainersForFlatten",
    value: function makeContainersForFlatten(sort) {
      var _this2 = this;

      var leaves = this.data.map(function (c, i) {
        return new Container({
          data: [c],
          label: "".concat(i),
          visualspace: {
            width: 0,
            height: 0,
            posX: 0,
            posY: 0,
            padding: {
              top: 0,
              left: 0,
              bottom: 0,
              right: 0
            }
          },
          parent: _this2,
          children: undefined
        });
      });

      if (sort) {
        leaves.sort(function (a, b) {
          var v1 = a.data[0][sort.key] || '';
          var v2 = b.data[0][sort.key] || '';
          var ascending = sort.direction === 'ascending' ? 1 : -1;
          return (sort.type === 'numerical' ? Number(v1) > Number(v2) : v1 > v2) ? ascending : -1 * ascending;
        });
      }

      return leaves;
    }
  }, {
    key: "makeContainersForNumericalVar",
    value: function makeContainersForNumericalVar(sharingDomain, subgroup) {
      var _this3 = this;

      var extent = d3.extent(sharingDomain, function (d) {
        return Number(d[subgroup.key]);
      });
      var containers = [];

      if (subgroup.numBin) {
        var tempScale = d3.scaleLinear().domain([0, subgroup.numBin]).range(extent);
        var tickArray = d3.range(subgroup.numBin + 1).map(tempScale); // const nullGroup = this.data.filter((d) => d[subgroup.key] === '');

        var valueGroup = this.data.filter(function (d) {
          return d[subgroup.key] !== '';
        });
        var bins = d3.histogram().domain(extent).thresholds(tickArray).value(function (d) {
          // @ts-ignore
          return Number(d[subgroup.key]); // @ts-ignore
        })(valueGroup);
        containers = bins.map(function (d) {
          return new Container({
            // @ts-ignore
            data: d,
            label: "".concat(d.x0, "-").concat(d.x1),
            visualspace: {
              width: 0,
              height: 0,
              posX: 0,
              posY: 0,
              padding: {
                top: 0,
                left: 0,
                bottom: 0,
                right: 0
              }
            },
            parent: _this3,
            children: undefined
          });
        });
      }

      return containers;
    }
  }, {
    key: "getKeys",
    value: function getKeys(data, groupby) {
      var myNest = d3.nest().key(function (d) {
        // @ts-ignore
        return d[groupby];
      }).entries(data);
      return myNest.map(function (d) {
        return d.key;
      });
    }
  }, {
    key: "emptyContainersFromKeys",
    value: function emptyContainersFromKeys(data, groupby) {
      // @ts-ignore
      return this.getKeys(data, groupby).map(function (key) {
        return new Container({
          parent: undefined,
          children: undefined,
          label: key,
          data: [],
          visualspace: {
            width: 0,
            height: 0,
            posX: 0,
            posY: 0,
            padding: {
              top: 0,
              left: 0,
              bottom: 0,
              right: 0
            }
          }
        });
      });
    }
  }]);

  return Container;
}();
//# sourceMappingURL=Container.js.map